@@ -20,7 +20,7 @@ pub trait CloudLocation {
     fn as_str(&self) -> &'static str;
 }
 
-#[derive(Clone, Copy, Debug, Eq, Hash, PartialEq, JsonSchema)]
+#[derive(Clone, Copy, Debug, Eq, Hash, PartialEq, JsonSchema, Serialize, Deserialize)]
 pub enum Location {
     Aws(aws::AwsRegion),
     Azure(azure::AzureRegion),
